@@ -2,7 +2,7 @@ use crate::render::portable::utils::{render_index_file, render_static_files};
 use crate::render::portable::ItemRenderer;
 use crate::render::Renderer;
 use crate::spec::ItemsSpec;
-use anyhow::Result;
+use anyhow::{bail, Context, Result};
 use structopt::StructOpt;
 
 pub(crate) mod cli;
@@ -12,7 +12,15 @@ pub(crate) mod utils;
 
 fn main() -> Result<()> {
     let opt = cli::Datavzrd::from_args();
-    let config = ItemsSpec::from_file(opt.config).unwrap();
+    let config = ItemsSpec::from_file(&opt.config).context(format!(
+        "Could not find config file under given path {:?}",
+        &opt.config
+    ))?;
+
+    if !opt.output.exists() {
+        bail!("Given output directory {:?} does not exist", &opt.output);
+    }
+
     render_index_file(&opt.output, &config)?;
     render_static_files(&opt.output)?;
 
